
*** MULTILEVEL MODELING CURRENT MOOD ***

*** Outcome 2: current mood - energetic arousal - multilevel modeling - AVAILABLE-CASE ANALYSIS ***

use "/Users/angelakunzler/RQ4_current mood_arousal/D_RQ4a_dataset3_current mood_FINAL.dta"

* a. Means by time for energetic arousal
rename Mzp time
tabulate time, summarize(Total_energetic_arousal)
* b. Create filter variable to count the number of missing values for the maximum set of variables in order to estimate the multilevel models with the same number of participants
egen nmiss1 = rowmiss(Total_energetic_arousal)
* c. Scatterplot by individual participants.
twoway scatter Total_energetic_arousal time, connect (L) title("Arousal") by(userid)
* d. Exclusion of six cases with ≤ 3 observations.
drop if userid == 23 | userid == 24 | userid == 28 | userid == 29 | userid == 30 | userid == 48 

* e. Scatterplots to explore the data structure and test the linear change over time 
twoway scatter Total_energetic_arousal time, title(change "Arousal")
twoway scatter Total_energetic_arousal time, connect (L) title(change "Arousal")
twoway scatter Total_energetic_arousal time, title("Arousal") by(userid)
twoway scatter Total_energetic_arousal time, connect (L) title("Arousal") by(userid)
// Linear trend for change in energetic arousal over time 
 
* f. Calculation of different linear mixed effects models

// 1) Null model: without predictors
mixed Total_energetic_arousal || userid:, mle variance, if nmiss1==0
estat ic
estat icc
estimates store FitNull

// 2) (2-level) Random intercept model (fixed linear time/fixed level-1 predictor time with random intercepts, i.e. intercepts allowed to vary randomly)
// Only random intercept --> only userid: on right sight
mixed Total_energetic_arousal time || userid:, mle variance, if nmiss1==0
estat ic
estimates store FitRandInt_time
lrtest FitNull FitRandInt_time

// 3a) (2-level) Random-coefficients model (random linear time/level-1 predictor time with random intercepts and random slopes)
// extends previous model by allowing for a random slope on time
// Initially no covariance structure is specified for random effects --> MIXED uses the default Independent structure
mixed Total_energetic_arousal time || userid: time, mle variance, if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time

// 3b) (2-level) Random-coefficients model 
// with pre-specified covariance structure: exchangeable or Compound Symmetry (CS) covariance matrix
mixed Total_energetic_arousal time || userid: time, mle variance covariance(exc), if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time
 
// 3c) (2-level) Random-coefficients model 
// with pre-specified covariance structure: unstructured covariance matrix
mixed Total_energetic_arousal time || userid: time, mle variance covariance(unstructured), if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time

* h. Fitting plots for best-fitting model; energetic arousal: (2-level) Random-coefficients model with unstructured covariance matrix
// Plotting of observed and predicted values (see Stata manual, p. 324)
predict fitTotal_energetic_arousal
twoway scatter Total_energetic_arousal fitTotal_energetic_arousal time, connect (L) ytitle("Average Total_energetic_arousal") by(userid)
// If predicted values closely match the observed values, this confirms the adequacy of the model
// Generate standardized residuals and see whether they follow a standard normal distribution --> as they should in any good-fitting model (Stata manual, p. 9; mixed postestimation commands)
predict rs, rstandard
summarize rs
qnorm rs

* i. Testing of assumptions for multilevel modeling
// 1) Linearity assumption: scatterplots (see also already above under point e.)
twoway scatter Total_energetic_arousal time, connect (L) title("Total_energetic_arousal") by(userid)
// 2) Normal distribution of residuals
// see Stata manual (p. 325)
// see above under h.
// Using histograms
// a. Predict level-1 residuals
predict res,res
// b. Predict residuals for random slopes & intercepts
predict rslp rint,reffects
// c. Generate a variable to pick one individual for the histogram
byso userid: gen indv = _n == 1
// d. Create the histogram and combine the graphs for visualization
hist res, normal title ("Residuals") saving (x1,replace)
hist rslp if indv==1, normal title ("Residuals for random slopes") saving(x2,replace)
hist rint if indv==1, normal title ("Residuals for random intercepts") saving(x3,replace)
graph combine x1.gph x2.gph x3.gph, col(2)
// 3) Homoscedasticity (homogeneity of residual variances): scatterplots of (standardized) residuals and predicted/fitted values
// i.e. in model only with level-1 predictor: equal variances of level-1 residuals at each level of level-1 predictor
predict stand, rstandard
predict fit, fitted
twoway(scatter stand fit), yline(0)

*** MULTIPLE IMPUTATION (MI) WITH ACCOUNTING FOR CLUSTERING IN DATA (i.e. multilevel model)***
// In order to compare the mixed command as available-case analysis with the results of mixed command based on imputed data
// see https://www.stata.com/support/faqs/statistics/clustering-and-mi-impute/
// strategy 2

* j. Multiple imputation for three outcomes to be imputed
mi set wide // 
mi convert wide, clear
mi register imputed Total_valence Total_energetic_arousal Total_calmness
rename userid cluster
mi impute mvn Total_valence Total_energetic_arousal Total_calmness = , add(5) by(cluster, noreport) rseed(123)

* k. Multilevel modeling after multiple imputation (using command 'mi estimate')

rename cluster userid

// NOT PERFORMED AND ANALYZED FOR DISSERTATION.
// 1) Null model - NOT analyzed.
mi estimate: mixed Total_energetic_arousal || userid:, mle variance
// 2) (2-level) Random intercept model (fixed linear time/fixed level-1 predictor Mzp wird random intercepts, i.e. intercepts allowed to vary rand omly) - NOT analyzed.
mi estimate: mixed Total_energetic_arousal time || userid:, mle variance
// 3a) (2-level) Random-coefficients model (random linear time/level-1 predictor Mzp with random intercepts and random slopes) - NOT analyzed.
 mi estimate: mixed Total_energetic_arousal time || userid: time, mle variance
// Initially no covariance structure specified for random effects --> MIXED uses the default Independent structure
// 3b) (2-level) Random-coefficients model - NOT analyzed.
// with pre-specified covariance structure (exchangeable or Compound Symmetry)
 mi estimate: mixed Total_energetic_arousal time || userid: time, mle variance covariance(exc)

// RELEVANT FOR ANALYSIS (BEST MODEL FIT IN AVAILABLE-CASE ANALYSIS)
// 3c) (2-level) Random-coefficients model 
// with pre-specified covariance structure (unstructured)
 mi estimate: mixed Total_energetic_arousal time || userid: time, mle variance covariance(unstructured)
 
