
*** MULTILEVEL MODELING END-OF-DAY MEASURES ***

*** Outcome 1: end-of-day measures - well-being - multilevel modeling - AVAILABLE-CASE ANALYSIS ***

use "/Users/angelakunzler/RQ4_end-of-day_well-being/D_RQ4b_dataset3_end-of-day_FINAL.dta"

* a. Means by time for well-being
tabulate time, summarize(Wellbeing)
* b. Create filter variable to count the number of missing values for the maximum set of variables in order to estimate the multilevel models with the same number of participants
egen nmiss1 = rowmiss(Wellbeing)
* c. Scatterplot by individual participants.
twoway scatter Wellbeing time, connect (L) title("Wellbeing") by(userid)
* d. Exclusion of eight cases with ≤ 3 observations.
drop if userid == 23 | userid == 24 | userid == 26 | userid == 27 | userid == 28 | userid == 36 | userid == 40 | userid == 48 

* e. Scatterplots to explore the data structure and test the linear change over time 
twoway scatter Wellbeing time, title(change "Well-being")
twoway scatter Wellbeing time, connect (L) title(change "Well-being")
twoway scatter Wellbeing time, title("Well-being") by(userid)
twoway scatter Wellbeing time, connect (L) title("Well-being") by(userid)
// Linear trend for change in well-being over time 
 
* f. Calculation of different linear mixed effects models

// 1) Null model: without predictors
mixed Wellbeing || userid:, mle variance, if nmiss1==0
estat ic
estat icc
estimates store FitNull

// 2) (2-level) Random intercept model (fixed linear time/fixed level-1 predictor time with random intercepts, i.e. intercepts allowed to vary randomly)
// Only random intercept --> only userid: on right sight
mixed Wellbeing time || userid:, mle variance, if nmiss1==0
estat ic
estimates store FitRandInt_time
lrtest FitNull FitRandInt_time

// 3a) (2-level) Random-coefficients model (random linear time/level-1 predictor time with random intercepts and random slopes)
// extends previous model by allowing for a random slope on time
// Initially no covariance structure is specified for random effects --> MIXED uses the default Independent structure
mixed Wellbeing time || userid: time, mle variance, if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time

// 3b) (2-level) Random-coefficients model 
// with pre-specified covariance structure: exchangeable or Compound Symmetry (CS) covariance matrix
mixed Wellbeing time || userid: time, mle variance covariance(exc), if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time
 
// 3c) (2-level) Random-coefficients model 
// with pre-specified covariance structure: unstructured covariance matrix
mixed Wellbeing time || userid: time, mle variance covariance(unstructured), if nmiss1==0
estat ic
estimates store FitRandSlope_time
lrtest FitRandInt_time FitRandSlope_time

* h. Fitting plots for best-fitting model; well-being: (2-level) Random-coefficients model with unstructured covariance matrix
// Plotting of observed and predicted values (see Stata manual, p. 324)
predict fitWellbeing
twoway scatter Wellbeing fitWellbeing time, connect (L) ytitle("Average Well-being") by(userid)
// If predicted values closely match the observed values, this confirms the adequacy of the model
// Generate standardized residuals and see whether they follow a standard normal distribution --> as they should in any good-fitting model (Stata manual, p. 9; mixed postestimation commands)
predict rs, rstandard
summarize rs
qnorm rs

* i. Testing of assumptions for multilevel modeling
// 1) Linearity assumption: scatterplots (see also already above under point e.)
twoway scatter Wellbeing time, connect (L) title("Well-being") by(userid)
// 2) Normal distribution of residuals
// see Stata manual (p. 325)
// see above under h.
// Using histograms
// a. Predict level-1 residuals
predict res,res
// b. Predict residuals for random slopes & intercepts
predict rslp rint,reffects
// c. Generate a variable to pick one individual for the histogram
byso userid: gen indv = _n == 1
// d. Create the histogram and combine the graphs for visualization
hist res, normal title ("Residuals") saving (x1,replace)
hist rslp if indv==1, normal title ("Residuals for random slopes") saving(x2,replace)
hist rint if indv==1, normal title ("Residuals for random intercepts") saving(x3,replace)
graph combine x1.gph x2.gph x3.gph, col(2)
// 3) Homoscedasticity (homogeneity of residual variances): scatterplots of (standardized) residuals and predicted/fitted values
// i.e. in model only with level-1 predictor: equal variances of level-1 residuals at each level of level-1 predictor
predict stand, rstandard
predict fit, fitted
twoway(scatter stand fit), yline(0)

*** MULTIPLE IMPUTATION (MI) WITH ACCOUNTING FOR CLUSTERING IN DATA (i.e. multilevel model)***
// In order to compare the mixed command as available-case analysis with the results of mixed command based on imputed data
// see https://www.stata.com/support/faqs/statistics/clustering-and-mi-impute/
// strategy 2

* j. Multiple imputation only for well-being
mi set wide // 
mi convert wide, clear
mi register imputed Wellbeing
mi impute regress Wellbeing, add(5) by(userid, noreport) rseed(123)
// not possible for three end-of-day measures simultaneously (too few observations)

* k. Multilevel modeling after multiple imputation (using command 'mi estimate')

// NOT PERFORMED AND ANALYZED FOR DISSERTATION.
// 1) Null model - NOT analyzed.
mi estimate: mixed Wellbeing || userid:, mle variance
// 2) (2-level) Random intercept model (fixed linear time/fixed level-1 predictor Mzp wird random intercepts, i.e. intercepts allowed to vary rand omly) - NOT analyzed.
mi estimate: mixed Wellbeing time || userid:, mle variance
// 3a) (2-level) Random-coefficients model (random linear time/level-1 predictor Mzp with random intercepts and random slopes) - NOT analyzed.
 mi estimate: mixed Wellbeing time || userid: time, mle variance
// Initially no covariance structure specified for random effects --> MIXED uses the default Independent structure
// 3b) (2-level) Random-coefficients model - NOT analyzed.
// with pre-specified covariance structure (exchangeable or Compound Symmetry)
 mi estimate: mixed Wellbeing time || userid: time, mle variance covariance(exc)

// RELEVANT FOR ANALYSIS (BEST MODEL FIT IN AVAILABLE-CASE ANALYSIS)
// 3c) (2-level) Random-coefficients model 
// with pre-specified covariance structure (unstructured)
 mi estimate: mixed Wellbeing time || userid: time, mle variance covariance(unstructured)
 
