
****** PS-MATCHING ******


*******************************************************************************************************************************************************
**** PRE-ANALYSES ****
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"

* Variables considered as potential covariates: age, gender education, mental health (GHQ-28), sum microstressors (MIMIS), sum macrostressors (LE Checklist)
* All variables metric except for gender (already coded with 0/1) and education

* Between-group comparison of IG and CG in potential covariates (non-matched data) at pre-test
tabstat Alter_aktuell_2019 Prae_GHQ28_gesamt Prae_DH_Haeufigkeit Prae_LE_Haeufigkeit, by(Bedingung) stat(mean sd min) nototal
* a) Metric variables:
	ttest Alter_aktuell_2019, by(Bedingung)
	ttest Prae_GHQ28_gesamt, by(Bedingung)
	ttest Prae_DH_Haeufigkeit, by(Bedingung)
	ttest Prae_LE_Haeufigkeit, by(Bedingung) unequal // due to differing SDs in the two groups for this variable (see tabstat)
* b) Categorial vaariables: gender, education:
	tabulate Geschlecht Bedingung, chi2
	tabulate Hoechster_Bildungsabschluss_num Bedingung, chi2
*******************************************************************************************************************************************************

*******************************************************************************************************************************************************
**** 7 STEPS OF PS MATCHING ****

**** STEP 1: Estimation of Propensity Score (PS) (= probability for an individual to participate in a treatment given observed covariates) ****

**** STEP 2 (within STEP 1): Common support/overlap assumption, i.e. Minima Maxima comparison vs trimming method ****
// Minima and Maxima comparison: all observations/participants are deleted whose propensity score is smaller than the minimum and larger than the maximum in the opposite group
// Trimming procedure: common support region is defined as those values of PS that have positive density within both the treated=1 and treated=0 
// distribution; any PS points for which the estimated density is exactly zero are excluded
// In addition, to ensure that densities are strictly positive, densities have to exceed zero by a treshold amount q
// i.e. not only the PS points for which the estimated density is exactly zero, but also an additional q percent of the remaining PS points for which // the estimated density is positive but very low are excluded
// trim(integer): imposes common support by dropping # percent of the treatment observations at which the pscore density of the control observations 
// is the lowest

************ 1a) 1-to-1 matching (1-nearest neighbors matching) WITHOUT replacement ************

* First without common command (= Minima Maxima comparison)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement logit ate
// 82 in common support region
* Assessment of matching quality
* Visual analysis
// distribution of PS (propensity score histogram by treatment status)
psgraph
// PS density graph before AND after matching
pstest _pscore, density both
* Statisical tests of matching quality
// Based on two-tailed t-tests (for each covariate) it is investigated whether across the groups
// Sig. group differences in the covariates when unmatched should not be there anymore after the matching 
// all covariates have to be listed
// option both: status before and after matching is presented
// %bias: numbers relative difference in one covariate between groups
// %reduct|bias|: indicates relative reduction of this difference by matching
// Comparison of determination coefficient Pseudo-R2 und LR chi2-Test before and after matching
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum
// Balancing of covariates between groups results in Pseudo R2 near 0 after matching
// LR chi2 test should not be significant anymore; i.e. none of the covariates used should be appropriate to predict the group assignment


// Different options tested for 1-to-1-matching without replacement 
// --> However, matching quality (see psgraph, pstest) better with common option everytime

* Common command (i.e. Minima and Maxima comparison)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement common logit ate
// 60 participants in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

* Trimming method (q = 1%)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement trim(1) logit ate
// 82 participants in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

* Trimming method (q = 5%)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement trim(5) logit ate
// 82 participants in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

* Trimming method (q = 25%)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement trim(25) logit ate
// 64 participants in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

* Therefore, final 1-to-1 matching WITH common command:
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement common logit ate
// 60 participants in common support region
// Common command maintained across all other matching algorithms
* Assessment of matching quality
psgraph
// Green columns: Frequency of cases of IG in certain interval of PS
// Red columns: Frequency of cases in CG in certain interval of PS
// Blue columns: Cases in CG that were excluded from the analysis due to non-meeting of Common Support condition
// Orange columns: Cases in IG that were excluded from the analysis due to non-meeting of Common Support condition
* --> There is certain heterogeneity between groups
// although cases in IG as well as CG concentrate on interval of PS from 0.1 to approx. 0.9
// --> Individuals are already relatively similar in the covariates used (graphically)
// see graph 3
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 
*******************************************************************************************************************************************************



**** PS scores BEFORE matching ****
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement common logit ate

pstest _pscore, treated(Bedingung) density raw //Alternative graph of Propensity Scores in two groups before matching (see raw)
summarize _pscore // Summary range Propensity Score overall
twoway (kdensity _pscore if _treated==1) (kdensity _pscore if _treated==0, lpattern(dash)), legend( label( 1 "treated") label( 2 "control")) xtitle("propensity scores BEFORE matching") saving(before, replace)



*******************************************************************************************************************************************************
**** STEP 3: Based on graphs for PS, R2 and p value of LR test: Selection of ONE matching algorithm from the 12 algorithms tested (see below) ****
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"

*************************1a) 1-to-1 matching WITHOUT replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) noreplacement common logit ate
// 60 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

*************************1b) 1-to-1 matching WITH replacement*************************************************
//WITH replacement
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

*************************2) 2-Nearest neighbors matching (default is 1); only possible with replacement (= default)*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(2) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

*************************3) 3-Nearest neighbors matching (default is 1); only possible with replacement (= default)*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(3) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************4) 4-Nearest neighbors matching (default is 1); only possible with replacement (= default)*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(4) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 
 
**************************5a) Caliper matching; WITHOUT replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) caliper(0.2) noreplacement common logit ate
// 40 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************5b) Caliper matching; WITH replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) caliper(0.2) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************6a) Caliper matching (0.3 instead of 0.2); WITHOUT replacement *************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) caliper(0.3) noreplacement common logit ate
// 43 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************6b) Caliper matching (0.3 instead of 0.2); WITH replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) caliper(0.3) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************7a) Radius caliper matching (0.2); WITHOUT replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, radius caliper(0.2) out(Stressorbel) noreplacement common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************7b) Radius caliper matching (0.2); WITH replacement*************************************************
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, radius caliper(0.2) out(Stressorbel) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

**************************8) Kernel matching; only possible with replacement (= default)*************************************************
//option kerneltype(normal) --> determines that as density function a normal distribution is used
//concerning bandwith standard/default 0.06 bwidth(0.06), which is automatically set in Stata
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, kernel k(normal) out(Stressorbel) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

***** --> BEST MATCHING QUALITY is found for 2-nearest neighbor matching (only possible WITH replacement) *****
*******************************************************************************************************************************************************



*******************************************************************************************************************************************************
**** STEP 4: Selection of variables ****
// --> For final algorithm, the number of covariates (that should potentially be included besides age, gender, education) is determined based on // statistical significance
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"

* Only age, gender, education (see above)
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(2) common logit ate
// 61 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, both sum 

* Adding of GHQ-28 at pre-test
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_GHQ28_gesamt, out(Stressorbel) neighbor(2) common logit ate
// 58 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_GHQ28_gesamt, both sum 
// GHQ-28 is no sig. predictor; matching quality decreases by adding --> GHQ-28 is omitted again

* Adding of stressor exposure (MIMIS) at pre-test
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_DH_Haeufigkeit, out(Stressorbel) neighbor(2) common logit ate
// 58 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_DH_Haeufigkeit, both sum 
// Stressor exposure (microstressors) is no sig. predictor; matching quality relatively stable compared to without MIMIS --> MIMIS is omitted again

* Adding of stressor exposure (LE Checklist) at pre-test
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_LE_Haeufigkeit, out(Stressorbel) neighbor(2) common logit ate
// 40 in common support region
* Assessment of matching quality
psgraph
pstest _pscore, density both
pstest Alter_aktuell_2019 Geschlecht dum1 dum2 dum3 Prae_DH_Haeufigkeit Prae_LE_Haeufigkeit, both sum 
// Stressor exposure (macrostressors) is no sig. predictor; matching quality decreases by adding --> LE Checklist is omitted again
*******************************************************************************************************************************************************



*******************************************************************************************************************************************************
**** STEP 5: SENSITIVITY ANALYSIS FOR FINAL ALGORITHM & FINAL MODEL ****

***** --> FINAL ALGORITHM & MODEL: 2-nearest matching with replacement with age, gender, education at pre-test *****
// final algorithm is conducted again for further steps of PS matching
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(2) common logit ate
// 61 in common support region

**** SENSITIVITY ANALYSIS ****
// to determine how strongly an unmeasured variable must influence the selection process in order to undermine the implications of matching analysis
// Creation of new variable which describes individual treatment effects (delta_Stressorbel);
// is calculated after matching is conducted
gen delta_Stressorbel = Stressorbel - _Stressorbel if _treated==1 & _support==1
// Conduction of actual sensitivity analysis
// gamma indicates in which intervals and until which value of gamma, the Rosenbaum Bounds are calculated
// here: based on value 1, interval distances of 0.1 until a gamme of 2.0 selected for the calculation of Rosenbaum Bounds
rbounds delta_Stressorbel, gamma(1(0.1)2)
// Only upper significance limits (sig+) are relevant as they represent positive selection and, thus, potential over-estimation of true treatment // effects
// in scenario 1 (i.e. gamma = 1), treatment effect is significant with p = 0.04; 
// i.e. in case of absence of all selection and confounding processes, the estimated treatment effect is significant
// For other scenarios of gamma, treatment effect is not sig. anymore
// Sensitivity analysis probably not so relevant in Train4Positivity as - even without matching - no positive treatment effect is available
// In case positive treatment effect had been found, sig+ would be interpreted as follows: 
// The higher gamma and the estimated effect is still significant, the more robust are effect estimations
// Hodhes-Lehman point estimator: (based on assumption of additive treatment effects): indicates how large the treatment effect would still be
// if a confounding factor distorts the odds ratio to be in the treatment group, on the level of a certain gamma value
*******************************************************************************************************************************************************



*******************************************************************************************************************************************************
**** STEP 6: 2-nearest neighbor matching (with replacement) - 2. CONDUCTION OF FINAL MATCHING WITH TEFFECTS INSTEAF OF PSMATCH2 ****
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"
// teffects by default according to logit model and with replacement
// teffects psmatch: teffects psmatch (y) (t x1 x2), gen(match) atet
teffects psmatch (Stressorbel) (Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3), nneighbor(2) gen(match) atet
// ATET = 1.8 (SE: 3.53)
// for density plot after teffects psmatch:
tebalance density
// Postestimation measures after teffects psmatch
predict ps0 ps1, ps // get probability scores for control and treat observation 
predict y0 y1, po // get potential outcomes for each matching 
predict te // get treatment effect (Y1-Y0) for eaach observation
// Testing of Overlap assumption after teffects psmatch
teffects overlap
// teffects overlap plots the estimated densities of the probability of getting each treatment level after teffects
// --> can be used to check whether overlap assumption is violated
// overlap assumption is satisfied when there is a chance of seeing observations in both the control and treatment groups at each combination of // covariate values

// Result:
// Estimated density of predicted probabilities that treated individual is not assigned to Bedingung LifeStress has most of its mass near 0
// Estimated density of predicted probabilities that untreated individual is not assigned to Bedingung LifeStress has most of ita mass near 1
// The two have little mass in the region in which they overlap
// --> Overlap assumption probably violated
*******************************************************************************************************************************************************



*******************************************************************************************************************************************************
**** STEP 7: SAVING OF MATCHED DATA FOR FURTHER ANALYSES  AND POST-TEST COMPARISON) ****
use "/Users/angelakunzler/Downloads/D_RQ1_1.2_dataset2_FINAL.dta"
// 2-nearest neighbor matching (with replacement) is conducted again
psmatch2 Bedingung Alter_aktuell_2019 Geschlecht dum1 dum2 dum3, out(Stressorbel) neighbor(2) common logit ate
// Keep matched data on support
keep if _support==1
// Matched data are saved
use "/Users/angelakunzler/D_RQ1_1.2_dataset2_FINAL_matched data.dta"

**** POST-TEST COMPARISON BETWEEN MATCHED PARTICIPANTS OF TRAIN4POSITIVITY AND LIFESTRESS ****
* Test distribution of Stressorbel in two groups based on matched data
tabstat Stressorbel, by(Bedingung) stat(mean sd)
* Testing of assumptions for independent t-test
// Boxplot diagrams for metric variables to test for outliers
graph box Stressorbel Alter_aktuell_2019 Prae_GHQ28_gesamt Prae_DH_Haeufigkeit Prae_LE_Haeufigkeit
// Normality assumption using Shapiro-Wilk Test for each treatment group
by Bedingung, sort : swilk Stressorbel
// Levene's test for homogeneity of variances between treatment groups
robvar Stressorbel, by(Bedingung)

* POST-ANALYSIS (AFTER 3W) BETWEEN IG AND CG CONCERNING PERCEIVED SEVERITY OF MICROSTRESSORS ****
// Independent t-test used for the following reasons (Schafer & Kang, 2008; Stuart, 2008)
// Conditioning on the variables that were used in the matching process is sufficient
// PS matching does not guarantee that the individuals pairs will be well-matched on the full set of covariates, only that groups of individuals with similar PS will have similar covariate distribution
// Thus, it seems also reasonable to simply pool all the matches into matched treated and control groups and run analyses using the groups as a whole, rather than using the individual matched pairs (as in paired t-test)

// a. Independent t-test (equal variances)
ttest Stressorbel, by(Bedingung)
// For effect size calculation (Cohen's d):
help esize
esize twosample Stressorbel, by(Bedingung)
*******************************************************************************************************************************************************


